:Ingress
@rem PTF/Efix Installer Driver Script (AEs)

@if     defined echo echo %echo%
@if not defined echo echo off
setLocal
Set edition=AEs

set ScriptVersion=1.17.1.60
set ScriptUpdate=10/11/02

set PTFNUM=ptf_5
set PTFVER=4.0.5
set PTFDescription=IBM WebSphere Application Server V%PTFVER% %Edition% Fixpack

Set QUOTENOTE=NOTE:  Do not use quotes.
Set WASEXAMPLE=Ex. Use C:\WebSphere\AppServer  NOT "C:\WebSphere\AppServer"
Set JDKEXAMPLE=Ex. Use C:\WebSphere\AppServer\java  NOT "C:\WebSphere\AppServer\java"
Set IHSEXAMPLE=Ex. Use C:\IBM HTTP Server  NOT "C:\IBM HTTP Server"
Set APACHEEXAMPLE=Ex. Use C:\Apache Groups\Apache  NOT "C:\Apache Groups\Apache"

echo.
echo %PTFDescription%
echo.
echo Installation Program
echo Script Version: %ScriptVersion%
echo Script Update: %ScriptUpdate%
echo.

:testTools
echo Testing availability of update tools.
echo.
if not exist LogEvent.bat goto noLogger
echo The Logging tool ('LogEvent.bat') is available.
if not exist GetInput.exe goto noInputer
echo The Input tool ('GetInput.exe') is available.
echo.
goto z_testTools

:noLogger
echo ERROR: No Logging tool ('LogEvent.bat') is available.
echo.
goto EgressWithError

:noInputer
echo ERROR: No Input tool ('GetInput.exe') is available.
echo.
goto EgressWithError

:z_testTools
echo The required update tools are available.
echo.
if /I "%1" == "-silent"   goto forceTmp
goto checkLicense

:checkLicense
echo FixPak License:
echo    The software samples, tools, updates, fixes and other materials ("Code")
echo    available in this archive for WebSphere Application Server ("Program")
echo    are copyrighted materials. By typing "Accept", you agree that the Code
echo    is provided under, and is subject to, the terms and conditions of the
echo    license agreement(s) which accompanied or were contained in the copy or
echo    copies of the Program for which you are obtaining the Code. You are not
echo    authorized to install or use the Code except as part of a Program for which
echo    you have a valid Proof of Entitlement or other authorization as specified
echo    in such license agreement(s). You further agree that you will comply with
echo    all applicable laws and export regulations. [Accept/Reject]
GetInput LRESP "" "GetLic.bat"
call GetLic.bat & del GetLic.bat
  
if /I (%LRESP%) == (Accept) goto forceTmp
echo !! Halting Install !!
echo Install will not continue without Accepting License Agreement
goto Egress
  

rem Make sure that the temporary directory is usable.

:forceTmp
if not defined TMP goto tmpNotSet
echo Noted temporary directory from in the environment ('TMP'):
echo %TMP%
echo.
goto testTemp

:tmpNotSet
echo No temporary directory is set in the environment ('TMP).
echo The current directory will be used.
echo.
set TMP=.
goto testTemp

:testTemp
echo Testing that the temporary directory is writable.
echo.
ver > "%TMP%\ZZXRM.tmp"
if NOT exist "%TMP%\ZZXRM.tmp" goto cannotWriteTmp
del "%TMP%\ZZXRM.tmp"
echo The temporary directory is writable.
echo.
goto z_forceTmp

:cannotWriteTmp
echo The temporary directory is not writable.
echo.
goto EgressWithError

:z_forceTmp
goto testOS

:testOS
rem   Get Version
rem       Windows NT Version 4.0
rem       Microsoft Windows 2000 [Version 5.00.2195]

FOR /f "tokens=1-5*" %%a in ('ver') do Set t1=%%a& Set t2=%%b& set t3=%%c& set t4=%%d& set t5=%%e

if (%t1%%t2%)     == (WindowsNT)            Set OSName=NT&  Set OSVersion=%t4%
if (%t1%%t2%%t3%) == (MicrosoftWindows2000) Set OSName=W2K& Set OSVersion=%t5%
if (%t1%%t2%%t3%) == (MicrosoftWindowsXP)   Set OSName=XP&  Set OSVersion=%t5%
goto testSummary

:testSummary
GetInput SQLTS short "%TMP%\GetTS.Bat" & Call "%TMP%\GetTS.bat" & Del "%TMP%\GetTs.bat"
set STARTTIME=%SQLTS%

set SUMMARYBASE=Summary_%PTFNUM%_%STARTTIME%.log
set SUMMARYLOG="%TMP%\%SUMMARYBASE%"
set LEAVE_LOG=true

echo Using summary log:
echo %SUMMARYLOG%
echo.

echo Testing that the summary log can be written.
echo.
ver > %SUMMARYLOG%
if NOT exist %SUMMARYLOG% goto unableToWriteSummary
del %SUMMARYLOG%
echo The summary log can be written.
echo.
goto writeSummaryHeader

:unableToWriteSummary
echo The summary log is not writable.
echo.
goto EgressWithError

:writeSummaryHeader
call LogEvent BlankLine
call LogEvent echo %PTFDescription%
call LogEvent echo PTF Number: %PTFNUM%
call LogEvent echo TimeStamp: %STARTTIME%
call LogEvent echo Script Version: %ScriptVersion%
call LogEvent echo Script Update: %ScriptUpdate%
call LogEvent BlankLine
call LogEvent echo OS Name: %OSName%
call LogEvent echo OS Version: %OSVersion%
call LogEvent BlankLine
goto z_testSummary

:z_testSummary
goto parseOptions

:parseOptions
call LogEvent echo Parsing command line options:

rem 'SILENT' controls if this is a silent install.
rem
rem 'HELP' controls if help has been requested.
rem 'USAGE' controls is usage has been requsted.
rem
rem 'OVERWRITEBUJ' controls if backup jar's may be overwritten.
rem The possible values are blank or '-OverWriteBackupJar'.
rem
rem 'DEBUGMODE' is used to execute the installation script but
rem to perform no commands.

set SILENT=false

set HELP=false
set USAGE=false

set OVERWRITEBUJ=

set DEBUGMODE=false

rem Cycle through the parameters until an non-valid option is parsed, or
rem all of the parameters are exhausted, or one of the help options
rem is presented.

set SHOWNSILENT=false

:parseLoop
set VALIDPARM=false

if NOT "%1" == "" call LogEvent echo Parsing "%1"

if    "%1" == ""            goto completeParse
if /I "%1" == "-silent"     set SILENT=true& set VALIDPARM=true

if (%SILENT%) == (false) goto skipSilentMsg
if (%SHOWNSILENT%) == (true) goto skipSilentMsg
call LogEvent echo Silent mode has been enabled.
set SHOWNSILENT=true
:skipSilentMsg

if /I "%1" == "-?"          set USAGE=true& set VALIDPARM=true
if /I "%1" == "?"           set USAGE=true& set VALIDPARM=true
if /I "%1" == "Usage"       set USAGE=true& set VALIDPARM=true
if /I "%1" == "-Usage"      set USAGE=true& set VALIDPARM=true
if /I "%1" == "Help"        set HELP=true& set VALIDPARM=true
if /I "%1" == "-Help"       set HELP=true& set VALIDPARM=true
if /I "%1" == "-Debug"      set DEBUGMODE=true& set VALIDPARM=true
if (%VALIDPARM%) == (false) goto usageBadParam
if (%USAGE%) == (true)      goto usage
if (%HELP%) == (true)       goto help
shift
goto parseLoop

:usageBadParam
call LogEvent echo ERROR: The command line parameter "%1" is not valid.
call LogEvent BlankLine
call LogEvent echo Use the command line parameter -Usage to see usage information.
call LogEvent BlankLine
goto usage

:completeParse
call LogEvent echo Completed parsing command line options.
call LogEvent BlankLine
if (%SILENT%) == (true) set OverWriteBUJ=-OverWriteBackupJar
goto displayOptions

:usage
call LogEvent echo Usage has been requested.
call LogEvent BlankLine
echo Usage: install [ -options ]
echo.
echo This script performs the update for %PTFNUM% of the WebSphere Application Server.
echo.
echo Valid command line options include:
echo    -Silent     [ Enable silent mode ]
echo    -Help, help -? ?  [ Show help ]
echo    -usage      [ Show this usage information ]
echo.
echo A number of options are available through environment variables, as follows:
echo.
echo     SKIP_WAS = ( true , false )
echo     WAS_UPDATE_HOME = path
echo.
echo     SKIP_JDK = ( true , false )
echo     JDK_UPDATE_HOME = path
echo.
echo     INSTALL_IHS = ( true , false )
echo     IHS_UPDATE_HOME = path
echo.
echo     BACKUP_DIR = path
echo     LOGS_DIR = path
echo.
echo     TMP = path
echo.
echo     IPLANET_HOME = path
echo     IPLANET_VERSION = ( 4 , 6 )
echo.
echo     INSTALL_APACHE = (true , false )
echo     APACHE_UPDATE_HOME = path
echo.
if (%SILENT%) == (false) pause
goto completedSummary

:help
call LogEvent echo Help has been requested.
call LogEvent BlankLine
echo.
echo Use SKIP_WAS to disable the update the the WebSphere Application Server.
echo In silent mode the Application Server is updated by default.
echo For component-only installations (e.g.: plugin, admin console, tools, 
echo etc...) the Application Server must be updated.
echo.
echo Use WAS_UPDATE_HOME to specify the home for the Application Server.  In
echo silent mode, unless the Application Server update is disabled, the
echo Application Server home must be specified.
echo For component-only installations (e.g.: plugin, admin console, tools, 
echo etc...) the Application Server must be updated.
echo.
echo Use SKIP_JDK to disable the update of the Java Development Kit.
echo In silent mode, if available, the JDK will be updated by default.
echo.
echo Use JDK_UPDATE_HOME to specify the home for the Java Development Kit.
echo Normally, the JDK home will be computed relative to the Application
echo Server home.
echo.
echo Also use JDK_UPDATE_HOME to specify the location of the Java Development
echo Kit which is being used to run the update programs.  In silent mode, if
echo the Application Server update is disabled, or if no Java Development Kit
echo is available beneath the Application Server Home, the JDK home must be
echo specified to allow the update programs to run.
echo.
echo Use INSTALL_IHS to enable the update of the IBM HTTP Server.  In silent
echo mode, by default, the IBM HTTP Server is not updated.
echo.
echo Use IHS_UPDATE_HOME to specify the home of the IBM HTTP Server.  In
echo silent mode, when the IBM HTTP Server update is enabled, a home for the
echo IBM HTTP Server must be provided.
echo.
echo Use BACKUP_DIR to specify the location into which to put backup
echo files for the selected updates.  In silent mode, when a backup
echo directory is not specified, backup files are placed into the
echo first of the following locations which is writable:
echo.
echo    The Application Server Home
echo    The Current Directory
echo    The Temporary Directory
echo.
echo Use LOGS_DIR to specify the location into which to put log files,
echo including both the summary log file and log files for the selected
echo updates.  In silent mode, when a logs directory is not specified,
echo log files are placed in the first of the following locations which
echo are writable:
echo.
echo     The Application Server Home
echo     The Current Directory
echo     The Temporary Directory
echo.
echo The summary log is initially written to the temporary directory.
echo After the selected updates are performed the summary log is copied
echo into the logs directory.
echo.
echo Use IPLANET_HOME to specify the location of the config directory for
echo the iPlanet web server.  An example IPLANET_HOME would be:
echo C:\iplanet\servers\https-<hostname>\config
echo.
echo Use IPLANET_VERSION to specify the version of iPlanet that the user
echo would like to update.  There are only two valid values for IPLANET_VERSION
echo and they are 4 and 6.
echo.
echo Use INSTALL_APACHE to enable the update of the Apache web server in order
echo to add support for EAPI.  In silent mode, by default, the Apache web server
echo is not updated.
echo.
echo Use APACHE_UPDATE_HOME to specify the home of the Apache web server.  In
echo silent mode, when the Apache web server update is enabled, a home for the
echo Apache web server must be provided.
echo.
if (%SILENT%) == (false) pause
goto completedSummary

:displayOptions
call LogEvent BlankLine
call LogEvent echo Options:
call LogEvent BlankLine
call LogEvent echo Silent: %SILENT%
call LogEvent echo Debug: %DEBUGMODE%
call LogEvent BlankLine
goto displayEnvironment

:displayEnvironment
call LogEvent echo Environment Settings:
call LogEvent BlankLine
call LogEvent echo Skip Application Server Update ('SKIP_WAS'):
call LogEvent echo [ %SKIP_WAS% ]
call LogEvent BlankLine
call LogEvent echo Application Server Home ('WAS_UPDATE_HOME'):
call LogEvent echo [ %WAS_UPDATE_HOME% ]
call LogEvent BlankLine
call LogEvent echo Skip Java Development Kit Update ('SKIP_JDK'):
call LogEvent echo [ %SKIP_JDK% ]
call LogEvent BlankLine
call LogEvent echo Java Development Kit Home ('JDK_UPDATE_HOME'):
call LogEvent echo [ %JDK_UPDATE_HOME% ]
call LogEvent BlankLine
call LogEvent echo Force IBM HTTP Server Update ('INSTALL_IHS'):
call LogEvent echo [ %INSTALL_IHS% ]
call LogEvent BlankLine
call LogEvent echo IBM HTTP Server Home ('IHS_UPDATE_HOME'):
call LogEvent echo [ %IHS_UPDATE_HOME% ]
call LogEvent BlankLine
call LogEvent echo Backup Path ('BACKUP_DIR'):
call LogEvent echo [ %BACKUP_DIR% ]
call LogEvent BlankLine
call LogEvent echo Log Path ('LOGS_DIR'):
call LogEvent echo [ %LOGS_DIR% ]
call LogEvent BlankLine
call LogEvent echo Temporary Directory ('TMP'):
call LogEvent echo [ %TMP% ]
call LogEvent BlankLine
call LogEvent echo iPlanet Web Server Configuration Home ('IPLANET_HOME'):
call LogEvent echo [ %IPLANET_HOME% ]
call LogEvent BlankLine
call LogEvent echo iPlanet Web Server Version ('IPLANET_VERSION'):
call LogEvent echo [ %IPLANET_VERSION% ]
call LogEvent BlankLine
call LogEvent echo Force Apache EAPI Web Server Update ('INSTALL_APACHE'):
call LogEvent echo [ %INSTALL_APACHE% ]
call LogEvent BlankLine
call LogEvent echo Apache Web Server Home ('APACHE_UPDATE_HOME'):
call LogEvent echo [ %APACHE_UPDATE_HOME% ]
call LogEvent BlankLine
echo.
echo %PTFDescription%
echo Please shut down the Application Server, AAT and any WebServers that 
echo might be running. If not the PTF may not be installed properly.
echo.
if (%SILENT%) == (true) goto silentPause
pause
goto z_parseOptions

:silentPause
call LogEvent echo Pause to allow user to view warning.
GetInput Sleep 10 quiet
call LogEvent echo Pause complete.
goto z_parseOptions

:z_parseOptions
goto checkUpdate


:checkUpdate

rem Section for handling detection of the application server update.
rem

rem Inputs:
rem     SKIP_WAS
rem     WAS_UPDATE_HOME
rem
rem Outputs:
rem     SKIP_WAS
rem     WAS_UPDATE_HOME
rem
rem Exits:
rem     update_jdk
rem     exit
rem

:checkUpdateWas
call LogEvent echo Checking Application Server update.
call LogEvent BlankLine

set PRODUCT_FILE=properties\com\ibm\websphere\product.xml
set PROPERTIES_FILE=deploytool\itp\install\install.properties
set PLUGIN_FILE=bin\plugin_common.dll

if not defined SKIP_WAS set SKIP_WAS=false

if NOT (%SKIP_WAS%) == (true) goto verifyWasEnabled
call LogEvent echo The Application Server update was disabled from the environment.
call LogEvent BlankLine
goto z_checkUpdateWas

:verifyWasEnabled
if (%SILENT%) == (true) goto wasEnabledSilent
goto verifyWasEnabledInterative


:verifyWasEnabledInterative
echo.
echo.
echo NOTE: For PTF upgrades on component-only installations (e.g.: plugin, admin console, tools) you must enter "Yes" to update the Application Server.
call LogEvent GetInput YorN "Update the Application Server (yes/no)?" "%TMP%\updWas.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto wasEnabledInteractive
call LogEvent echo The Application Server update was disabled by the user.
call LogEvent BlankLine
set SKIP_WAS=true
goto z_checkUpdateWas

:wasEnabledInteractive
call LogEvent echo The Application Server update was enabled by the user.
call LogEvent BlankLine
if not defined WAS_UPDATE_HOME goto noWasHomeInteractive
call LogEvent echo An application server home is available from the environment:
call LogEvent echo %WAS_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent GetInput YorN "Accept the Application Server Home from the environment (yes/no)?" "%TMP%\useApp.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto getWasHomeInteractive
goto testWasHomeInteractive

:noWasHomeInteractive
call LogEvent echo No Application Server home was specified in the environment ('WAS_UPDATE_HOME').
call LogEvent BlankLine

:getWasHomeInteractive
call LogEvent echo %QUOTENOTE%
call LogEvent echo %WASEXAMPLE%
call LogEvent GetInput WAS_UPDATE_HOME "Enter the Application Server Home:[Example: C:\WebSphere\AppServer]" "%TMP%\getApp.bat"
call LogEvent BlankLine

:testWasHomeInteractive
if exist "%WAS_UPDATE_HOME%\%PRODUCT_FILE%" goto wasHomeVerifiedProductInteractive
if exist "%WAS_UPDATE_HOME%\%PROPERTIES_FILE%" goto wasHomeVerifiedPropertiesInteractive
if exist "%WAS_UPDATE_HOME%\%PLUGIN_FILE%" goto wasHomeVerifiedPluginInteractive
call LogEvent echo ERROR: The specified Application Server Home cannot be used:
call LogEvent echo      Neither the signature product file,the signature properties files
call LogEvent echo      nor the signature plugin file could be found under the
call LogEvent echo      specified directory.
call LogEvent echo      The following path was used to search for the signature product file:
call LogEvent echo      [ %WAS_UPDATE_HOME%\%PRODUCT_FILE% ]
call LogEvent echo      The following path was used to search for the signature properties file:
call LogEvent echo      [ %WAS_UPDATE_HOME%\%PROPERTIES_FILE% ]
call LogEvent echo      The following path was used to search for the signature plugin file:
call LogEvent echo      [ %WAS_UPDATE_HOME%\%PLUGIN_FILE% ]
call LogEvent BlankLine
call LogEvent GetInput YorN "Cancel this update (yes/no)?" "%TMP%\canUpd.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto getWasHomeInteractive
call LogEvent echo This update is being stopped.
call LogEvent BlankLine
goto complete

:wasHomeVerifiedProductInteractive
call LogEvent echo The Application Server Home contains a signature product file:
call LogEvent echo %PRODUCT_FILE%
call LogEvent BlankLine
goto z_checkUpdateWas

:wasHomeVerifiedPropertiesInteractive
call LogEvent echo The Application Server Home contains a signature properties file:
call LogEvent echo %PROPERTIES_FILE%
call LogEvent BlankLine
goto z_checkUpdateWas

:wasHomeVerifiedPluginInteractive
call LogEvent echo The Application Server Home contains a signature plugin file:
call LogEvent echo %PLUGIN_FILE%
call LogEvent BlankLine
goto z_checkUpdateWas


:wasEnabledSilent
call LogEvent echo The Application Server update is enabled.
call LogEvent BlankLine

if defined WAS_UPDATE_HOME goto wasHomeSetSilent
call LogEvent echo ERROR: The Application Server update is enabled, but
call LogEvent echo no Application Server Home ('WAS_UPDATE_HOME') value was set.
call LogEvent BlankLine
goto complete

:wasHomeSetSilent
call LogEvent echo The Application Server home ('WAS_UPDATE_HOME') is set in the environment:
call LogEvent echo %WAS_UPDATE_HOME%
call LogEvent BlankLine

if exist "%WAS_UPDATE_HOME%\%PRODUCT_FILE%" goto wasHomeVerifiedProductSilent
if exist "%WAS_UPDATE_HOME%\%PROPERTIES_FILE%" goto wasHomeVerifiedPropertiesSilent
if exist "%WAS_UPDATE_HOME%\%PLUGIN_FILE%" goto wasHomeVerifiedPluginSilent
call LogEvent echo ERROR: The specified Application Server Home cannot be used:
call LogEvent echo      Neither the signature product file, the signature properties file
call LogEvent echo      nor the signature plugin file could be found under the
call LogEvent echo      specified directory.
call LogEvent echo      The following path was used to search for the signature product file:
call LogEvent echo      [ %WAS_UPDATE_HOME%\%PRODUCT_FILE% ]
call LogEvent echo      The following path was used to search for the signature properties file:
call LogEvent echo      [ %WAS_UPDATE_HOME%\%PROPERTIES_FILE% ]
call LogEvent echo      The following path was used to search for the signature plugin file:
call LogEvent echo      [ %WAS_UPDATE_HOME%\%PLUGIN_FILE% ]

call LogEvent BlankLine
goto complete

:wasHomeVerifiedProductSilent
call LogEvent echo The Application Server home has a signature product file:
call LogEvent echo %PRODUCT_FILE%
call LogEvent BlankLine
goto z_checkUpdateWas

:wasHomeVerifiedPropertiesSilent
call LogEvent echo The Application Server home has a signature properties file:
call LogEvent echo %PROPERTIES_FILE%
call LogEvent BlankLine
goto z_checkUpdateWas

:wasHomeVerifiedPluginSilent
call LogEvent echo The Application Server home has a signature plugin file:
call LogEvent echo %PLUGIN_FILE%
call LogEvent BlankLine
goto z_checkUpdateWas

:z_checkUpdateWas
goto checkJDK


rem Section for handling detection of JDK update.
rem

rem Inputs:
rem     SILENT
rem     INSTALL_APP_SERVER
rem     SKIP_JDK
rem     JDK_UPDATE_HOME
rem
rem Outputs:
rem     SKIP_JDK
rem     JDK_UPDATE_HOME
rem     IS_WAS_JDK
rem
rem Exits:
rem     updateIhs
rem     complete

:checkJDK

call LogEvent echo Locating JDK, and checking for JDK update.
call LogEvent BlankLine

set JAVA_SUB_PATH=jre\bin\java.exe
if not defined SKIP_JDK set SKIP_JDK=false
set IS_WAS_JDK=false

call LogEvent echo Locating Application Server JDK.
call LogEvent BlankLine

if (%SKIP_WAS%) == (false) goto check_was_java
call LogEvent echo The Application Server is not being updated; skipping
call LogEvent echo Application Server JDK test.
call LogEvent BlankLine
set JDK_FROM_WAS=
goto determine_jdk

:check_was_java
call LogEvent echo The Application Server is being updated; testing the
call LogEvent echo Application Server JDK.
call LogEvent BlankLine
if not exist "%WAS_UPDATE_HOME%\java\%JAVA_SUB_PATH%" goto no_was_java
call LogEvent echo Located "%JAVA_SUB_PATH%" beneath "%WAS_UPDATE_HOME%\java".
call LogEvent BlankLine
call LogEvent echo The Application Server JDK is available for use.
call LogEvent BlankLine
set JDK_FROM_WAS=%WAS_UPDATE_HOME%\java
goto determine_jdk

:no_was_java
call LogEvent echo Cannot find "%JAVA_SUB_PATH%" beneath "%WAS_UPDATE_HOME%\java".
call LogEvent BlankLine
call LogEvent echo The Application Server JDK cannot be used.
call LogEvent BlankLine
set JDK_FROM_WAS=
goto determine_jdk

:determine_jdk
call LogEvent echo Determining the JDK for use.
call LogEvent BlankLine
call LogEvent echo Note that a JDK must be available for performing updates,
call LogEvent echo even if the JDK is not being updated.
call LogEvent BlankLine

if (%SILENT%) == (false) goto interactive_jdk

if not defined JDK_UPDATE_HOME goto silent_no_env_jdk
call LogEvent echo A JDK is available from the environment:
call LogEvent echo %JDK_UPDATE_HOME%
call LogEvent BlankLine

if NOT exist "%JDK_UPDATE_HOME%\%JAVA_SUB_PATH%" goto silent_bad_env_jdk
call LogEvent echo Accepting the JDK from the environment.
call LogEvent BlankLine
goto use_jdk

:silent_bad_env_jdk
call LogEvent echo "%JDK_UPDATE_HOME%" does not have "%JAVA_SUB_PATH%".
call LogEvent BlankLine
call LogEvent echo ERROR: Cannot use the JDK from the environment.
call LogEvent BlankLine
goto complete

:silent_no_env_jdk
call LogEvent echo No JDK is available from the environment.
call LogEvent BlankLine

if not defined JDK_FROM_WAS goto silent_no_was_jdk
rem The WAS JDK, if set, has already been tested.
call LogEvent echo An Application Server JDK is available and will be used.
call LogEvent BlankLine
set JDK_UPDATE_HOME=%JDK_FROM_WAS%
set IS_WAS_JDK=true
goto use_jdk

:silent_no_was_jdk
call LogEvent echo No JDK is available from the Application Server.
call LogEvent BlankLine
call LogEvent echo ERROR: Unable to determine JDK
call LogEvent BlankLine
goto complete


:interactive_jdk

set ORIG_JDK=%JDK_UPDATE_HOME%

:interactive_jdk_loop

set JDK_UPDATE_HOME=%ORIG_JDK%

if not defined JDK_UPDATE_HOME goto interactive_no_env_jdk

:ask_about_env_jdk
call LogEvent echo A JDK is available from the environment:
call LogEvent echo %JDK_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent GetInput YorN "Use the environment specified JDK (yes/no)?" "%TMP%\useEnJdk.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto ignore_env_jdk

if exist "%JDK_UPDATE_HOME%\%JAVA_SUB_PATH%" goto accept_env_jdk
call LogEvent echo "%JDK_UPDATE_HOME%" does not have "%JAVA_SUB_PATH%".
call LogEvent BlankLine
call LogEvent echo The environment JDK cannot be used.
call LogEvent BlankLine
set JDK_UPDATE_HOME=

call LogEvent GetInput YorN "Cancel this update (yes/no)?" "%TMP%\canUpd.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto ignore_env_jdk
call LogEvent echo This update is being stopped.
call LogEvent BlankLine
goto complete

:accept_env_jdk
call LogEvent echo Accepting the JDK from the environment.
call LogEvent BlankLine
goto use_jdk

:ignore_env_jdk
call LogEvent echo Ignoring the environment specified JDK.
call LogEvent BlankLine
set JDK_UPDATE_HOME=
goto interactive_check_was_jdk

:interactive_no_env_jdk
call LogEvent echo No JDK is available from the environment.
call LogEvent BlankLine
goto interactive_check_was_jdk

:interactive_check_was_jdk
if not defined JDK_FROM_WAS goto no_jdk_yet_ask

call LogEvent echo A WebSphere Application Server JDK is available:
call LogEvent echo %JDK_FROM_WAS%.
call LogEvent BlankLine
call LogEvent GetInput YorN "Use the Application Server JDK (yes/no)?" "%TMP%\useWsJdk.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto no_jdk_yet_ask
call LogEvent echo The Application Server JDK is being used.
call LogEvent BlankLine
set JDK_UPDATE_HOME=%JDK_FROM_WAS%
set IS_WAS_JDK=true
goto use_jdk

:no_jdk_yet_ask
call LogEvent echo No JDK is available.
call LogEvent echo %QUOTENOTE%
call LogEvent echo %JDKEXAMPLE%
call LogEvent GetInput JDK_UPDATE_HOME "Specify JDK for use:" "%TMP%\specJdk.bat"
call LogEvent BlankLine
if not exist "%JDK_UPDATE_HOME%\%JAVA_SUB_PATH%" goto unusable_user_jdk
call LogEvent echo "%JDK_UPDATE_HOME%" has "%JAVA_SUB_PATH%".
call LogEvent BlankLine
call LogEvent echo Accepting the user specified JDK.
call LogEvent BlankLine
goto use_jdk

:unusable_user_jdk
call LogEvent echo "%JDK_UPDATE_HOME%" does not have "%JAVA_SUB_PATH%".
call LogEvent BlankLine
call LogEvent echo The user specified JDK cannot be used.
call LogEvent BlankLine
set JDK_UPDATE_HOME=

call LogEvent GetInput YorN "Cancel this update (yes/no)?" "%TMP%\canUpd.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto interactive_jdk_loop
call LogEvent echo This update is being stopped.
call LogEvent BlankLine
goto complete

:use_jdk
call LogEvent echo The following JDK home directory will be used:
call LogEvent echo %JDK_UPDATE_HOME%
call LogEvent BlankLine
goto check_update_jdk

:check_update_jdk
if (%SKIP_JDK%) == (true) goto do_not_update_jdk_env

if (%SILENT%) == (false) goto confirm_update_jdk
goto do_update_jdk_def

:confirm_update_jdk
if (%SKIP_WAS%) == "false" goto skipJDKUpdateWarning
call LogEvent echo WARNING: The WebSphere Application Server is being updated.
call LogEvent echo WARNING: An update of the JDK is recommended.
call LogEvent echo WARNING: The updated Application Server typically requires
call LogEvent echo WARNING: the updated JDK for use.

:skipJDKUpdateWarning
call LogEvent GetInput YorN "Perform update of the JDK (yes/no)?" "%TMP%\doJdk.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto do_not_update_jdk_user
goto do_update_jdk_user

:do_not_update_jdk_env
call LogEvent echo The JDK will not be updated as specified in the
call LogEvent echo environment ('SKIP_JDK').
call LogEvent BlankLine
goto do_not_update_jdk

:do_not_update_jdk_user
call LogEvent echo The JDK will not be update per user request.
call LogEvent BlankLine
goto do_not_update_jdk

:do_update_jdk_def
call LogEvent echo Silent Mode: The JDK update will be performed.
call LogEvent BlankLine
goto do_update_jdk

:do_update_jdk_user
call LogEvent echo The JDK will be updated per user request.
call LogEvent BlankLine
goto do_update_jdk

:do_not_update_jdk
set SKIP_JDK=true
goto checkIPlanet

:do_update_jdk
set SKIP_JDK=false
goto checkIPlanet

rem Section for handling detection of iPlanet update.
rem

rem Inputs:
rem     SILENT
rem     IPLANET_HOME
rem     IPLANET_VERSION
rem
rem Outputs:
rem     IPLANET_HOME
rem     IPLANET_VERSION

:checkIPlanet
call LogEvent echo Checking for iPlanet web server update
call LogEvent BlankLine
if (%SILENT%) == (true) goto iPlanetSilent
if (%SILENT%) == (false) goto iPlanetInteractive

:iPlanetSilent
call LogEvent echo iPlanet Web Server Support
call LogEvent echo WebSphere Application Server %PTFVER% supports the
call LogEvent echo iPlanet 6 web server along with iPlanet 4.  
call LogEvent echo The installer will now check to see if the environment
call LogEvent echo variable IPLANET_HOME and IPLANET_VERSION have been set.
call LogEvent BlankLine
if not defined IPLANET_HOME goto iPlanetSilentEmptyPath
goto iPlanetSilentDirCheck

:iPlanetSilentEmptyPath
call LogEvent echo The environment variable IPLANET_HOME is null and
call LogEvent echo this is a silent install, therefore the installer
call LogEvent echo will not attempt to make changes to the iPlanet web
call LogEvent echo server configuration.
call LogEvent BlankLine
set IPLANET=
if not defined IPLANET_VERSION goto iPlanetSilentEmptyVersion
goto checkIHS

:iPlanetSilentEmptyVersion
call LogEvent echo The environment variable IPLANET_VERSION is null and
call LogEvent echo this is a silent install, therefore the installer
call LogEvent echo will not attempt to make changes to the iPlanet web
call LogEvent echo server configuration.
call LogEvent BlankLine
set IPLANET=
goto checkIHS

:iPlanetSilentDirCheck
if not exist "%IPLANET_HOME%" goto iPlanetSilentBadHome
if exist "%IPLANET_HOME%" goto iPlanetSilentVersionCheck

:iPlanetSilentVersionCheck
call LogEvent echo The path set for environment IPLANET_HOME is a valid
call LogEvent echo directory. 
call LogEvent echo IPLANET_HOME=%IPLANET_HOME%
call LogEvent echo The iPlanet version will now be checked.
call LogEvent BlankLine
if not (%IPLANET_VERSION%) == (4) if not (%IPLANET_VERSION%) == (6) goto iPlanetSilentBadVersion
set IPLANET=-iPlanetHome "%IPLANET_HOME%" -iPlanetVersion "%IPLANET_VERSION%" -silent
call LogEvent echo The value set for environment IPLANET_VERSION is valid.
call LogEvent echo IPLANET_VERSION=%IPLANET_VERSION%
call LogEvent echo The iPlanet configuration update will occur.
call LogEvent BlankLine
goto checkIHS  
 
:iPlanetSilentBadHome
call LogEvent echo The value for the environment variable IPLANET_HOME
call LogEvent echo does not exist. No iPlanet changes will be made.
set IPLANET=
call LogEvent BlankLine
goto checkIHS 
 
:iPlanetSilentBadVersion
call LogEvent echo the value specified for environment IPLANET_VERSION is
call LogEvent echo not 4 or 6.  Please change the environment according to
call LogEvent echo the version of iPlanet you have installed.
call LogEvent echo No iPlanet changes will be made.
call LogEvent BlankLine
set IPLANET=
goto checkIHS
               
:iPlanetInteractive
call LogEvent echo iPlanet Web Server Support
call LogEvent echo WebSphere Application Server %PTFVER% supports the
call LogEvent echo iPlanet 6 and iPlanet 4 web servers.  The installer
call LogEvent echo will add or update the necessary lines to the
call LogEvent echo configuration file(s) in order for iPlanet to work 
call LogEvent echo properly with WebSphere %PTFVER%. 
call LogEvent GetInput YorN "Update iPlanet web server configuration for support by WebSphere (yes/no)?" "%TMP%\doIPlanet.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto iPlanetInteractiveCheckPath
call LogEvent BlankLine
call LogEvent echo No iPlanet web server configuration update will occur.
call LogEvent BlankLine
set IPLANET=
goto checkIHS

:iPlanetInteractiveCheckPath
if not defined IPLANET_HOME goto iPlanetInteractiveEmptyPrompt
call LogEvent echo An iPlanet home is available from the environment IPLANET_HOME:
call LogEvent echo %IPLANET_HOME%
call LogEvent BlankLine
call LogEvent GetInput YorN "Use the environment specified IPLANET_HOME (yes/no)?" "%TMP%\correctIPlanet.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto iPlanetInteractiveEmptyPrompt
goto iPlanetInteractiveDirCheck

:iPlanetInteractiveEmptyPrompt
call LogEvent echo %QUOTENOTE%
call LogEvent echo "Example: C:\iPlanet\Servers\https-<hostname>\config"
call LogEvent GetInput IPLANET_HOME "Enter the path to the iPlanet configuration directory:" "%TMP%\iPlanetPath.bat"
if not exist "%IPLANET_HOME%" goto iPlanetBadHome
goto iPlanetInteractiveDirCheck

:iPlanetInteractiveDirCheck
if not exist "%IPLANET_HOME%" goto iPlanetBadHome
call LogEvent echo The path specified for IPLANET_HOME exists.
call LogEvent echo %IPLANET_HOME%
goto iPlanetInteractiveVersionCheck

:iPlanetInteractiveVersionCheck
if not defined IPLANET_VERSION goto iPlanetInteractiveVersionPrompt
call LogEvent echo An iPlanet version is available from the environment IPLANET_VERSION:
call LogEvent echo IPLANET_VERSION=%IPLANET_VERSION%
call LogEvent BlankLine
call LogEvent GetInput YorN "Use the environment specified IPLANET_VERSION (yes/no)?" "%TMP%\correctIPlanetVersion.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto iPlanetInteractiveVersionPrompt
goto iPlanetInteractiveVersionVerify

:iPlanetInteractiveVersionPrompt
call LogEvent BlankLine
call LogEvent echo Please enter the version number of the iPlanet web server
call LogEvent echo to be updated.
call LogEvent GetInput IPLANET_VERSION "Enter '4' for a 4.x.x web server or '6' for a 6.x.x web server: " "%TMP%\iPlanetPath.bat"
goto iPlanetInteractiveVersionVerify

:iPlanetInteractiveVersionVerify
if not (%IPLANET_VERSION%) == (4) if not (%IPLANET_VERSION%) == (6) goto iPlanetBadVersion
set IPLANET=-iPlanetHome "%IPLANET_HOME%" -iPlanetVersion "%IPLANET_VERSION%"
call LogEvent echo The IPLANET_VERSION is valid, the update will occur.
call LogEvent BlankLine
goto checkIHS


:iPlanetBadVersion
call LogEvent echo The version specified for IPLANET_VERSION is not '4' or '6'.
call LogEvent BlankLine
call LogEvent GetInput YorN "Cancel this update (yes/no)?" "%TMP%\canUpd.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto iPlanetInteractiveVersionPrompt
call LogEvent echo This update is being stopped.
call LogEvent BlankLine
goto complete

:iPlanetBadHome
call LogEvent BlankLine
call LogEvent echo The path specified for IPLANET_HOME could not be found
call LogEvent GetInput YorN "Update iPlanet web server configuration for support by WebSphere (yes/no)?" "%TMP%\doIPlanet.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto iPlanetInteractiveEmptyPrompt
goto checkIHS


rem Section for handling dection of HTTP server update.
rem

rem Inputs:
rem     INSTALL_IHS
rem     IHS_UPDATE_HOME
rem
rem Outputs:
rem     INSTALL_IHS
rem     IHS_UPDATE_HOME
rem
rem Exits:
rem     complete
rem

:checkIHS

call LogEvent echo Checking for IBM HTTP Server update.
call LogEvent BlankLine

set IHS_CONFIG_FILE=conf\httpd.conf
if not defined INSTALL_IHS set INSTALL_IHS=false

if (%SILENT%) == (false) goto updateIhsInteractive
goto updateIhsSilent

:updateIhsSilent
if (%INSTALL_IHS%) == (true) goto checkIhsHomeSilent
call LogEvent echo Silent Mode: Update of the IBM HTTP Server is not enabled.
call LogEvent BlankLine
set INSTALL_IHS=false
goto z_checkIHS

:checkIhsHomeSilent
if defined IHS_UPDATE_HOME goto testIhsHomeSilent
call LogEvent echo ERROR: Silent Mode: The IBM HTTP Server update is enabled
call LogEvent echo but no IBM HTTP Server Home ('IHS_UPDATE_HOME') was specified.
call LogEvent BlankLine
goto complete

:testIhsHomeSilent
if exist "%IHS_UPDATE_HOME%\%IHS_CONFIG_FILE%" goto okIhsHomeSilent
call LogEvent echo ERROR: Silent Mode: The IBM HTTP Server update is enabled
call LogEvent echo but the specified IBM HTTP Server Home ('IHS_UPDATE_HOME')
call LogEvent echo does not have an IHS configuration file.
call LogEvent BlankLine
call LogEvent echo The path to the required configuration file is:
call LogEvent echo %IHS_CONFIG_FILE%
call LogEvent BlankLine
goto complete

:okIhsHomeSilent
call LogEvent echo Silent Mode: The IBM HTTP Server update is enabled.
call LogEvent BlankLine
call LogEvent echo The IBM HTTP Server Home was specified as:
call LogEvent echo %IHS_UPDATE_HOME%
call LogEvent BlankLine
goto z_checkIHS


:updateIhsInteractive
if (%INSTALL_IHS%) == (true) goto ihsEnabledFromEnvInteractive

call LogEvent echo Update of the IBM HTTP Server is not enabled from the
call LogEvent echo environment.
call LogEvent BlankLine
call LogEvent echo WARNING: If you install the IBM HTTP Server PTF, you may not
call LogEvent echo WARNING: be able to uninstall it cleanly.  The GSKit package
call LogEvent echo WARNING: will not be uninstalled.
call LogEvent BlankLine
call LogEvent GetInput YorN "Perform update of the IBM HTTP Server (yes/no)?" "%TMP%\doIhs.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto ihsEnabledByUserInteractive
call LogEvent echo Update of the IBM HTTP Server has been disabled by the user.
call LogEvent BlankLine
set INSTALL_IHS=false
goto z_checkIHS

:ihsEnabledFromEnvInteractive
call LogEvent echo Update of the IBM HTTP Server has been enabled from the environment.
call LogEvent BlankLine
goto getIhsHomeInteractive

:ihsEnabledByUserInteractive
call LogEvent echo Update of the IBM HTTP Server has been enabled by the user.
call LogEvent BlankLine
goto getIhsHomeInteractive

:getIhsHomeInteractive
if not defined IHS_UPDATE_HOME goto promptIhsHomeInteractive
call LogEvent echo Update An IBM HTTP Server home has been specified on the environment:
call LogEvent echo %IHS_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent GetInput YorN "Use this IBM HTTP Server home (yes/no)?" "%TMP%\useIhs.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto acceptIhsHomeFromEnvInteractive
call LogEvent echo Ignoring the environment set IBM HTTP Server home.
call LogEvent BlankLine
goto promptIhsHomeInteractive

:promptIhsHomeInteractive
call LogEvent echo %QUOTENOTE%
call LogEvent echo %IHSEXAMPLE%
call LogEvent GetInput IHS_UPDATE_HOME "Enter the IBM HTTP Server home:" "%TMP%\getIhs.bat"
call LogEvent BlankLine
goto testIhsHomeInteractive

:acceptIhsHomeFromEnvInteractive
call LogEvent echo Accepting the environment specified IBM HTTP Server home.
call LogEvent BlankLine
goto testIhsHomeInteractive

:testIhsHomeInteractive
if exist "%IHS_UPDATE_HOME%\%IHS_CONFIG_FILE%" goto okIhsHomeInteractive
call LogEvent echo The IBM HTTP Server home does not contain a configuration file.
call LogEvent BlankLine
call LogEvent echo The set IBM HTTP Server home is:
call LogEvent echo %IHS_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent echo The path to the required configuration file is:
call LogEvent echo %IHS_CONFIG_FILE%
call LogEvent BlankLine
set IHS_UPDATE_HOME=
call LogEvent GetInput YorN "Cancel this update (yes/no)?" "%TMP%\canUpd.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto getIhsHomeInteractive
call LogEvent echo This update is being stopped.
call LogEvent BlankLine
goto complete

:okIhsHomeInteractive
call LogEvent echo The IBM HTTP Server home contains the required configuration file.
call LogEvent BlankLine
call LogEvent echo The set IBM HTTP Server home is:
call LogEvent echo %IHS_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent echo The path to the required configuration file is:
call LogEvent echo %IHS_CONFIG_FILE%
call LogEvent BlankLine
set INSTALL_IHS=true
goto z_checkIHS

:z_checkIHS
goto checkApache

rem Section for handling detection of Apache update.
rem

rem Inputs:
rem     SILENT
rem     INSTALL_APACHE
rem     APACHE_UPDATE_HOME
rem
rem Outputs:
rem     INSTALL_APACHE
rem     APACHE_UPDATE_HOME

:checkApache
call LogEvent echo Testing for update of the Apache web server.
call LogEvent BlankLine
set APACHE_CONFIG_FILE=conf\httpd.conf
set APACHE_SECTION=
if not defined INSTALL_APACHE set INSTALL_APACHE=false

if (%SILENT%) == (false) goto updateApacheInteractive
goto updateApacheSilent

:updateApacheSilent
if (%INSTALL_APACHE%) == (true) goto checkApacheHomeSilent
call LogEvent echo Silent Mode: Update of the Apache web server is not enabled.
call LogEvent BlankLine
set APACHE_SECTION=
goto z_checkApache

:checkApacheHomeSilent
if defined APACHE_UPDATE_HOME goto testApacheHomeSilent
call LogEvent echo ERROR: Silent Mode: The Apache web server update is enabled
call LogEvent echo but no Apache Home ('APACHE_UPDATE_HOME') was specified.
call LogEvent BlankLine
goto complete

:testApacheHomeSilent
if exist "%APACHE_UPDATE_HOME%\%APACHE_CONFIG_FILE%" goto okApacheHomeSilent
call LogEvent echo ERROR: Silent Mode: The Apache update is enabled
call LogEvent echo but the specified Apache Home ('APACHE_UPDATE_HOME')
call LogEvent echo does not have an Apache configuration file.
call LogEvent BlankLine
call LogEvent echo The path to the required configuration file is:
call LogEvent echo %APACHE_UPDATE_HOME%\%APACHE_CONFIG_FILE%
call LogEvent BlankLine
goto complete

:okApacheHomeSilent
call LogEvent echo Silent Mode: The Apache web server update is enabled.
call LogEvent BlankLine
call LogEvent echo The Apache Home was specified as:
call LogEvent echo %APACHE_UPDATE_HOME%
call LogEvent BlankLine
goto determineSilentSpecified

rem The iPlanet section will already set the command line argument -silent
rem if the user chooses to update iPlanet.  Therefore this section will
rem check to see if the user has iPlanet enabled, if so then there is no
rem need to add "-silent" to the APACHE_SECTION variable.
:determineSilentSpecified
if defined IPLANET goto noSilentNeeded
set APACHE_SECTION=-ApacheHome "%APACHE_UPDATE_HOME%" -silent
goto z_checkApache

:noSilentNeeded
set APACHE_SECTION=-ApacheHome "%APACHE_UPDATE_HOME%"
goto z_checkApache

:updateApacheInteractive
if (%INSTALL_APACHE%) == (true) goto apacheEnabledFromEnvInteractive

call LogEvent echo Update of the Apache web server is not enabled from the
call LogEvent echo environment.
call LogEvent BlankLine
call LogEvent echo WARNING: If you install the Apache update, you must already
call LogEvent echo WARNING: have the EAPI patch installed with your web server.
call LogEvent echo WARNING: If you do not have this patch applied to the web
call LogEvent echo WARNING: server then following this update Apache will
call LogEvent echo WARNING: not start.
call LogEvent BlankLine
call LogEvent GetInput YorN "Perform update of the Apache web server (yes/no)?" "%TMP%\doApache.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto apacheEnabledByUserInteractive
call LogEvent echo Update of the Apache web server has been disabled by the user.
call LogEvent BlankLine
set INSTALL_APACHE=false
set APACHE_SECTION=
goto z_checkApache

:apacheEnabledFromEnvInteractive
call LogEvent echo Update of the Apache web server has been enabled from the environment.
call LogEvent BlankLine
goto getApacheHomeInteractive

:apacheEnabledByUserInteractive
call LogEvent echo Update of the Apache web server has been enabled by the user.
call LogEvent BlankLine
goto getApacheHomeInteractive

:getApacheHomeInteractive
if not defined APACHE_UPDATE_HOME goto promptApacheHomeInteractive
call LogEvent echo An Apache home has been specified on the environment:
call LogEvent echo APACHE_UPDATE_HOME:
call LogEvent echo %APACHE_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent GetInput YorN "Use this Apache web server home (yes/no)?" "%TMP%\useApache.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto acceptApacheHomeFromEnvInteractive
call LogEvent echo Ignoring the environment set Apache web server home.
call LogEvent BlankLine
goto promptApacheHomeInteractive

:promptApacheHomeInteractive
call LogEvent echo %QUOTENOTE%
call LogEvent echo %APACHEEXAMPLE%
call LogEvent GetInput APACHE_UPDATE_HOME "Enter the Apache web server home:" "%TMP%\getApache.bat"
call LogEvent BlankLine
goto testApacheHomeInteractive

:acceptApacheHomeFromEnvInteractive
call LogEvent echo Accepting the environment specified Apache home.
call LogEvent BlankLine
goto testApacheHomeInteractive

:testApacheHomeInteractive
if exist "%APACHE_UPDATE_HOME%\%APACHE_CONFIG_FILE%" goto okApacheHomeInteractive
call LogEvent echo The Apache web server home does not contain a configuration file.
call LogEvent BlankLine
call LogEvent echo The set Apache web server home is:
call LogEvent echo %APACHE_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent echo The path to the required configuration file is:
call LogEvent echo %APACHE_CONFIG_FILE%
call LogEvent BlankLine
set APACHE_UPDATE_HOME=
set APACHE_SECTION=
call LogEvent GetInput YorN "Cancel this update (yes/no)?" "%TMP%\canUpd.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto updateApacheInteractive
call LogEvent echo This update is being stopped.
call LogEvent BlankLine
goto complete

:okApacheHomeInteractive
call LogEvent echo The Apache home contains the required configuration file.
call LogEvent BlankLine
call LogEvent echo The set Apache home is:
call LogEvent echo %APACHE_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent echo The path to the required configuration file is:
call LogEvent echo %APACHE_CONFIG_FILE%
call LogEvent BlankLine
set INSTALL_APACHE=true
set APACHE_SECTION=-ApacheHome %APACHE_UPDATE_HOME%
goto z_checkApache

:z_checkApache
goto checkJ2C


rem Section for handling detection of J2C update.
rem

rem Inputs:
rem     SILENT
rem     JDK_UPDATE_HOME
rem     IS_WAS_JDK
rem     FORCEJ2C
rem
rem Outputs:
rem     INSTALL_J2C
rem     UPDATE_J2C

:checkJ2C
call LogEvent echo Testing for update of the J2C Connector Architecture.
call LogEvent BlankLine

set INSTALL_J2C=false
set UPDATE_J2C=false

if exist J2Cinstaller.jar goto testForJ2CUpdate
call LogEvent echo No J2C Update is available within this FixPack.
call LogEvent BlankLine
goto z_checkJ2C

:testForJ2CUpdate
if (%IS_WAS_JDK%) == (true) goto testJ2CTarget
call LogEvent echo The JDK specified for use is not the Application Server JDK.
call LogEvent echo The J2C update will not be performed.
call LogEvent BlankLine
goto z_checkJ2C

:testJ2CTarget
if exist "%JDK_UPDATE_HOME%\lib\j2c.jar" goto j2CIsPresent
call LogEvent echo The Connector Architecture (J2C) jar file is not present:
call LogEvent echo "%JDK_UPDATE_HOME%\lib\j2c.jar"
call LogEvent BlankLine

if (%FORCEJ2C%) == (true) goto j2CInstallForced
call LogEvent echo The Connector Architecture (J2C) installation has not been
call LogEvent echo forced by the environment ('FORCEJ2C').
call LogEvent BlankLine

if (%SILENT%) == (true) goto j2CInstallSkippedSilent

call LogEvent echo The Connector Architecture for WebSphere (J2C) is not present in
call LogEvent echo the specified installation.
call LogEvent BlankLine
call LogEvent echo The Connector Architecture for WebSphere (J2C) was delivered in
call LogEvent echo WebSphere Advanced Edition, release 4.0 as a technology preview.
call LogEvent echo This initial delivery was based upon the J2EE 1.3 specification,
call LogEvent echo which had not yet been released by Sun.  The specification has been
call LogEvent echo made generally available by Sun.  The Connector Architecture for
call LogEvent echo WebSphere is now available and may be installed by this update.
call LogEvent BlankLine
call LogEvent GetInput YorN "Install Connector Architecture for WebSphere (J2C) (yes/no)?" "%TMP%\instJ2c.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto installJ2CUser
goto skipJ2CUser

:j2cIsPresent
call LogEvent echo A J2C jar is present in the target JDK home.  An update
call LogEvent echo will be performed.
call LogEvent BlankLine
set UPDATE_J2C=true
goto z_checkJ2C

:j2CInstallForced
call LogEvent echo The installation of the Connector Architecture (J2C) has
call LogEvent echo been forced from the environment ('FORCEJ2C').
call LogEvent BlankLine
set INSTALL_J2C=true
goto z_checkJ2C

:j2CInstallSkippedSilent
call LogEvent echo Silent Mode: Skipping update of Connector Architecture (J2C).
call LogEvent BlankLine
goto z_checkJ2C

:installJ2CUser
call LogEvent echo By user request, the Connector Architecture (J2C) will be installed.
call LogEvent BlankLine
set INSTALL_J2C=true
goto z_checkJ2C

:skipJ2CUser
call LogEvent echo By user request, the Connector Architecture (J2C) will not be installed.
call LogEvent BlankLine
goto z_checkJ2C

:z_checkJ2C
goto checkLogs


:checkLogs
call LogEvent echo Determining location for log files, including the
call LogEvent echo final location for the summary log file.
call LogEvent BlankLine

rem call LogEvent echo Log files are usually placed under the WebSphere Application
rem call LogEvent echo server home.  However, log files may also be placed in the
rem call LogEvent echo following locations:
rem call LogEvent BlankLine
rem call LogEvent echo * In a directory specified through the environment ('LOGS_DIR')
rem call LogEvent echo * In the current directory
rem call LogEvent echo * In a user specified directory
rem call LogEvent echo * In the temporary directory ('TMP')
rem call LogEvent BlankLine
rem call LogEvent echo Unless logs are placed in the temporary directory, the summary
rem call LogEvent echo log will be copied into the logs directory at the end of
rem call LogEvent echo update processing.
rem call LogEvent BlankLine

if (%SILENT%) == (true) goto checkLogsSilent

set LOGS_ORIG=%LOGS_DIR%

:logsLoop
set LOGS_DIR=%LOGS_ORIG%

if (%SKIP_WAS%) == (true) goto requestLogLocation
if not defined LOGS_DIR goto tryWasLogs
call LogEvent echo A logs directory is specified in the environment:
call LogEvent echo %LOGS_DIR%
call LogEvent BlankLine
call LogEvent GetInput YorN "Use the environment logs directory (yes/no)?" "%TMP%\useEnvLg.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto tryWasLogs
call LogEvent echo Testing that the environment logs directory exists.
call LogEvent BlankLine
if NOT exist "%LOGS_DIR%" goto notExistLogsInteractive
call LogEvent echo The directory specified in the environment exists.
call LogEvent BlankLine
call LogEvent echo Testing that the environment logs directory is writable.
call LogEvent BlankLine
ver > "%LOGS_DIR%\ZZXRM.tmp"
if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto unableToWriteLogsEnv
del "%LOGS_DIR%\ZZXRM.tmp"
call LogEvent echo The environment logs directory is writable and has been accepted
call LogEvent echo for use.
call LogEvent BlankLine
goto z_checkLogs

:notExistLogsInteractive
call LogEvent echo ERROR: The environment logs directory does not exist.
call LogEvent BlankLine
goto logsLoop

:unableToWriteLogsEnv
call LogEvent echo ERROR: The environment logs directory is not writable.
call LogEvent BlankLine
goto logsLoop

:tryWasLogs
call LogEvent echo The WebSphere Application server will be updated.
call LogEvent BlankLine
call LogEvent GetInput YorN "Use the Application Server Logs directory (yes/no)?" "%TMP%\useWsLgs.bat"
call LogEvent BlankLine
if /I (%YorN%) == (yes) goto putLogsUnderWas

:requestLogLocation
call LogEvent GetInput YorN "Put logs in the current directory (yes/no)?" "%TMP%\inCur.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto requestLogsTmp

call LogEvent echo Testing that the current directory is writable.
call LogEvent BlankLine
ver > ".\ZZXRM.tmp"
if NOT exist ".\ZZXRM.tmp" goto unableToWriteLogsCurrent
del ".\ZZXRM.tmp"
call LogEvent echo The current directory is writable.
call LogEvent BlankLine
set LOGS_DIR=.
set LEAVE_LOG=false
call LogEvent echo Logs will be put in the current directory.
call LogEvent BlankLine
goto z_checkLogs

:unableToWriteLogsCurrent
call LogEvent echo The current directory is not writable.
call LogEvent BlankLine
goto logsLoop

:requestLogsTmp
call LogEvent GetInput YorN "Put logs in the temporary directory (yes/no)?" "%TMP%\inTmp.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto requestLogsUser
set LOGS_DIR=%TMP%
call LogEvent echo Logs will be put in the temporary directory.
call LogEvent BlankLine
goto z_checkLogs

:requestLogsUser
call LogEvent GetInput LOGS_DIR "What directory should be used for logs:" "%TMP%\logsLoc.bat"
call LogEvent BlankLine

call LogEvent echo Testing that the specified logs direcotry exists.
call LogEvent BlankLine
if NOT exist "%LOGS_DIR%" goto notExistLogsUser
call LogEvent echo The logs directory specified exists.
call LogEvent BlankLine                            
call LogEvent echo Testing that the specified logs directory is writable.
call LogEvent BlankLine
ver > "%LOGS_DIR%\ZZXRM.tmp"
if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto unableToWriteLogsUser
del "%LOGS_DIR%\ZZXRM.tmp"
call LogEvent echo The specified logs directory is writable.
call LogEvent BlankLine
call LogEvent echo Logs will be put in the directory:
call LogEvent echo %LOGS_DIR%
call LogEvent BlankLine
set LEAVE_LOG=false
goto z_checkLogs

:notExistLogsUser
call LogEvent echo ERROR: The logs directory specified does not exist.
call LogEvent BlankLine
goto logsLoop

:unableToWriteLogsUser
call LogEvent echo ERROR: The specified directory is not writable.
call LogEvent BlankLine
goto logsLoop

:checkLogsSilent
if not defined LOGS_DIR goto putLogsUnderWas
call LogEvent echo A logs directory has been set in the environment:
call LogEvent echo %LOGS_DIR%
call LogEvent BlankLine
call LogEvent echo Testing that the logs direcotry from the environment exists.
call LogEvent BlankLine
if NOT exist "%LOGS_DIR%" goto notExistLogsSilent
call LogEvent echo The logs directory specified in the environment exists.
call LogEvent BlankLine
call LogEvent echo Testing that the logs directory from the environment is writable.
call LogEvent BlankLine
ver > "%LOGS_DIR%\ZZXRM.tmp"
if NOT exist "%LOGS_DIR%\ZZXRM.tmp" goto unableToWriteLogsSilent
del "%LOGS_DIR%\ZZXRM.tmp"
call LogEvent echo The logs directory is writable.
call LogEvent BlankLine
call LogEvent echo Accepting the logs directory from the environment.
call LogEvent BlankLine
set LEAVE_LOG=false
goto z_checkLogs

:notExistLogsSilent
call LogEvent echo ERROR: The logs directory specified does not exist.
call LogEvent BlankLine
goto complete

:unableToWriteLogsSilent
call LogEvent echo ERROR: The logs directory is not writable.
call LogEvent BlankLine
goto complete

:putLogsUnderWas
if (%SKIP_WAS%) == (true) goto leaveLogsInTmp
set LOGS_DIR=%WAS_UPDATE_HOME%\logs
call LogEvent echo The logs, including the summary log file, will be
call LogEvent echo put in the WebSphere Application Server logs
call LogEvent echo directory:
call LogEvent echo %LOGS_DIR%
call LogEvent BlankLine
set LEAVE_LOG=false
goto z_checkLogs

:leaveLogsInTmp
call LogEvent echo The Application Server is not being updated.
call LogEvent echo Logs will be placed in the temporary directory:
call LogEvent echo %TMP%
call LogEvent BlankLine
goto z_checkLogs

:z_checkLogs
goto checkBackup


rem Section for determine where to put backup files.
rem
rem Inputs:
rem     SILENT
rem     BACKUP_DIR
rem     SKIP_WAS
rem     WAS_UPDATE_HOME
rem
rem Outputs:
rem    BACKUP_DIR
rem
rem Exits:
rem    performUpdates
rem    complete

:checkBackup
call LogEvent echo Determining the location for backup files.
call LogEvent BlankLine

rem call LogEvent echo Backup files may be placed in any of the
rem call LogEvent echo following locations:
rem call LogEvent echo * In a location specified in the environment ('BACKUP_DIR')
rem call LogEvent echo * In the WebSphere Application Server Home
rem call LogEvent echo * In the current directory.
rem call LogEvent echo * In a user specified directory.
rem call LogEvent echo * In the temporary directory ('TMP').
rem call LogEvent BlankLine
rem call LogEvent echo Typically, backup files are placed under the
rem call LogEvent echo WebSphere Application Server Home.
rem call LogEvent BlankLine
rem call LogEvent echo The update has particular requirements for the amount of
rem call LogEvent echo required for backup files.  Ensure that sufficient space
rem call LogEvent echo is available for backup files.
rem call LogEvent BlankLine

if (%SILENT%) == (true) goto checkBackupSilent

set ORIG_BACKUP=%BACKUP_DIR%

:checkBackupInteractive
set BACKUP_DIR=%ORIG_BACKUP%

if not defined BACKUP_DIR goto noEnvBackup
call LogEvent echo A directory for backup files has been specified
call LogEvent echo in the environment:
call LogEvent echo %BACKUP_DIR%
call LogEvent BlankLine
call LogEvent GetInput YorN "Use the environment specified backup directory (yes/no)?" "%TMP%\useEnBk.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto ignoreEnvBackup
call LogEvent echo Testing the existence of the backup directory.
call LogEvent BlankLine
if NOT exist "%BACKUP_DIR%" goto doesNotExistBackupEnv
call LogEvent echo The directory specified exists.
call LogEvent echo Testing the writability of the backup directory.
call LogEvent BlankLine
ver > "%BACKUP_DIR%\ZZXRM.tmp"
if NOT exist "%BACKUP_DIR%\ZZXRM.tmp" goto unableToWriteBackupEnv
del "%BACKUP_DIR%\ZZXRM.tmp"
call LogEvent echo The backup directory is writable and has been
call LogEvent echo accepted for use.
call LogEvent BlankLine
goto copyHelpers

:doesNotExistBackupEnv
call LogEvent echo ERROR: The backup directory set in the environment does not exist.
call LogEvent BlankLine
goto checkBackupInteractive

:unableToWriteBackupEnv
call LogEvent echo ERROR: The backup directory set in the environment is not writable.
call LogEvent BlankLine
goto checkBackupInteractive

:noEnvBackup
call LogEvent echo No backup directory is set in the environment.
call LogEvent BlankLine
goto tryWasBackupsInteractive

:ignoreEnvBackup
call LogEvent echo The backup directory set in the environment is being disregarded.
call LogEvent BlankLine

:tryWasBackupsInteractive
if (%SKIP_WAS%) == (true) goto askCurrentBackupsInteractive
call LogEvent echo A WebSphere Application server home is set:
call LogEvent echo %WAS_UPDATE_HOME%
call LogEvent BlankLine
call LogEvent GetInput YorN "Place backups under the WebSphere Application Server Home (yes/no)?" "%TMP%\useWasBk.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto ignoreWasBackupInteractive
call LogEvent echo Backups will be placed under the WebSphere Application Server Home.
call LogEvent BlankLine
set BACKUP_DIR=%WAS_UPDATE_HOME%
goto copyHelpers

:ignoreWasBackupInteractive
call LogEvent echo The WebSphere Application server home will not be used for backups.
call LogEvent BlankLine

:askCurrentBackupsInteractive
call LogEvent GetInput YorN "Place backups under the current directory (yes/no)?" "%TMP%\useCurBk.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto askBackupLocation

call LogEvent echo Testing the writability of the current directory.
call LogEvent BlankLine
ver > ".\ZZXRM.tmp"
if NOT exist ".\ZZXRM.tmp" goto failedCurrentBackupsInteractive
del ".\ZZXRM.tmp"
call LogEvent echo The current directory is writable.
call LogEvent BlankLine
set BACKUP_DIR=.
goto copyHelpers

:failedCurrentBackupsInteractive
call LogEvent echo ERROR: The current directory is not writable.
call LogEvent BlankLine
goto checkBackupInteractive

:askBackupLocation
call LogEvent echo A temporary directory is set:
call LogEvent echo %TMP%
call LogEvent BlankLine
call LogEvent GetInput YorN "Place backups under the temporary directory (yes/no)?" "%TMP%\useTmpBk.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto askBackupDirectory
call LogEvent echo Backups will be placed in the temporary directory.
call LogEvent BlankLine
set BACKUP_DIR=%TMP%
goto copyHelpers

:askBackupDirectory
call LogEvent GetInput BACKUP_DIR "Specify the directory for backups:" "%TMP%\setBk.bat"
call LogEvent BlankLine
call LogEvent echo Testing the existence of the backup directory.
if NOT exist "%BACKUP_DIR%" goto doesNotExistBackupDirInteractive
call LogEvent echo The directory specified exists.
call LogEvent BlankLine
call LogEvent echo Testing the writability of the specified directory.
ver > "%BACKUP_DIR%\ZZXRM.tmp"
if NOT exist "%BACKUP_DIR%\ZZXRM.tmp" goto failedBackupDirInteractive
del "%BACKUP_DIR%\ZZXRM.tmp"
call LogEvent echo The specified directory is writable.
call LogEvent BlankLine
call LogEvent echo Backups will be placed in the specified directory.
call LogEvent BlankLine
goto copyHelpers

:doesNotExistBackupDirInteractive
call LogEvent echo ERROR: The specified backup directory does not exist.
call LogEvent BlankLine
goto backupCancelUpdateInteractive

:failedBackupDirInteractive
call LogEvent echo ERROR: The specified backup directory is not writable.
call LogEvent BlankLine
goto checkBackupInteractive

:backupCancelUpdateInteractive
call LogEvent BlankLine
call LogEvent GetInput YorN "Cancel this update (yes/no)?" "%TMP%\canUpd.bat"
call LogEvent BlankLine
if /I (%YorN%) == (no) goto checkBackupInteractive
call LogEvent echo This update is being stopped.
call LogEvent BlankLine
goto complete
             
:checkBackupSilent
if not defined BACKUP_DIR goto noBackupEnv
call LogEvent echo A directory for backup files has been specified
call LogEvent echo in the environment:
call LogEvent echo %BACKUP_DIR%
call LogEvent BlankLine
call LogEvent echo Testing the existence of the backup directory.
call LogEvent BlankLine
if NOT exist "%BACKUP_DIR%" goto notExistBackupEnv
call LogEvent echo The backup directory specified exists.
call LogEvent BlankLine
call LogEvent echo Testing the writability of the backup directory.
call LogEvent BlankLine
ver > "%BACKUP_DIR%\ZZXRM.tmp"
if NOT exist "%BACKUP_DIR%\ZZXRM.tmp" goto unableToWriteBackupEnv
del "%BACKUP_DIR%\ZZXRM.tmp"
call LogEvent echo The backup directory is writable.
call LogEvent BlankLine
call LogEvent echo Backups will be placed in the directory specified in
call LogEvent echo environment.
call LogEvent BlankLine
goto copyHelpers

:noBackupEnv
call LogEvent echo No environment set backup directory is available.
call LogEvent BlankLine
goto tryWasBackups

:notExistBackupEnv
call LogEvent echo ERROR: The backup directory specified does not exist.
call LogEvent BlankLine
goto tryWasBackups

:unableToWriteBackupEnv
call LogEvent echo ERROR: The backup directory set in the environment ('BACKUP_DIR')
call LogEvent echo ERROR: is not writable.
call LogEvent BlankLine
goto complete

:tryWasBackups
if (%SKIP_WAS%) == (true) goto noWasBackups
set BACKUP_DIR=%WAS_UPDATE_HOME%
call LogEvent echo The WebSphere Application Server is being updated.
call LogEvent BlankLine
call LogEvent echo Backups will be placed in the Application Server home:
call LogEvent echo %BACKUP_DIR%
call LogEvent BlankLine
goto copyHelpers

:noWasBackups
call LogEvent echo The Application server is not being updated.
call LogEvent BlankLine
goto tryCurrentBackups

:tryCurrentBackups
call LogEvent echo Testing the writability of the current directory.
call LogEvent BlankLine
ver > ".\ZZXRM.tmp"
if NOT exist ".\ZZXRM.tmp" goto failedCurrentBackups
del ".\ZZXRM.tmp"
call LogEvent echo The current directory is writable.
call LogEvent BlankLine

call LogEvent echo Backups will be placed in the current directory.
call LogEvent BlankLine
set BACKUP_DIR=.
goto copyHelpers

:failedCurrentBackups
call LogEvent echo Backups will be written to the temporary directory ('TMP'):
call LogEvent echo %TMP%
call LogEvent BlankLine
set BACKUP_DIR=%TMP%
goto copyHelpers

:copyHelpers
if ("%BACKUP_DIR%") == (.) goto copyHelpersFalse
:copyHelpersTrue
    call LogEvent echo Copying helper files to the backup directory.
    copy GetInput.exe "%BACKUP_DIR%"
    copy LogEvent.bat "%BACKUP_DIR%"
    copy uninstall_ptf_5.bat "%BACKUP_DIR%"
    call LogEvent echo Copying helper files to the backup directory -- Done.
    call LogEvent BlankLine
    goto copyHelpersDone
:copyHelpersFalse
    call LogEvent echo The backup directory is the same as the current directory.
    call LogEvent echo Copies of helper files do not need to be made.
    call LogEvent BlankLine
:copyHelpersDone
goto z_checkBackup

:z_checkBackup
goto performUpdates

:performUpdates
call LogEvent echo About to perform selected updates.
call LogEvent BlankLine
if (%SILENT%) == (false) pause

:updateWAS
if (%SKIP_WAS%) == (true) goto skipUpdateWAS

set SectionName=UpdateApplicationServer

call LogEvent echo Updating the WebSphere Application Server.
call LogEvent BlankLine

set CommandName=RunApplicationServerUpdate
set CommandDescription=Run java on the supplied application server update jar file.
set CommandBackup=%BACKUP_DIR%\was40_%Edition%_%PTFNUM%_backup.jar
set CommandLog=%LOGS_DIR%\was40_%Edition%_%PTFNUM%.log

call LogEvent echo Running update from jar file:
call LogEvent echo was40_%Edition%_%PTFNUM%.jar
call LogEvent echo Running update against target:
call LogEvent echo %WAS_UPDATE_HOME%
call LogEvent echo Creating backup jar file:
call LogEvent echo %CommandBackup%
call LogEvent echo Creating update log file:
call LogEvent echo %CommandLog%
Call LogEvent BlankLine

rem --- Echo a hyperlink from the summary log file to the detail log file.

Set CMD="%JDK_UPDATE_HOME%\jre\bin\java" -jar was40_%Edition%_%PTFNUM%.jar -target "%WAS_UPDATE_HOME%" -backupJar "%CommandBackup%" -log "%CommandLog%" -TmpDir "%TMP%" %OverWriteBUJ% %IPLANET% %APACHE_SECTION%

Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
Call LogEvent echo %CMD%

if (%DEBUGMODE%) == (true) goto :skipWasCmd

Set errorlevel=
%CMD%
Set localRC=%errorlevel%
goto afterWasCmd

:skipWasCmd
call LogEvent echo DebugMode: Skipping Command
Set localRC=0

:afterWasCmd
call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine
if (%localRC%) NEQ (0) goto updateWASError
call LogEvent echo The update of the WebSphere Application Server was successful.
call LogEvent BlankLine
goto updateJDK

:skipUpdateWAS
call LogEvent echo The update of the WebSphere Application Server was disabled.
call LogEvent BlankLine
goto updateJDK

:updateWASError
call LogEvent echo An error occurred during the WebSphere Application Server update.
call LogEvent BlankLine
goto updateError

:updateJDK

if (%SKIP_JDK%) == (true) goto skipUpdateJDK

set SectionName=UpdateJDK

call LogEvent echo Updating the Java Development Kit.
call LogEvent BlankLine

call LogEvent echo Pausing 10 seconds to allow the JDK to settle.
GetInput Sleep 10 quiet
call LogEvent echo Completed pause.

if NOT exist "%TMP%\java_%PTFNUM%" goto :skipMakeSpace

call LogEvent echo Making space for the working copy of the JDK:
call LogEvent echo Target JDK Path: %TMP%\java_%PTFNUM%
call LogEvent BlankLine

set CommandName=MakeWorkJDKSpace
set CommandDescription=Make space for the working copy of the JDK
set CommandBackup=None is available
set CommandLog=None is available

set CMD=rmdir "%TMP%\java_%PTFNUM%" /S/Q

Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
Call LogEvent echo %CMD%

if (%DEBUGMODE%) == (true) goto :skipJdkPrep

rmdir "%TMP%\java_%PTFNUM%" /S/Q
set localRC=0
if exist "%TMP%\java_%PTFNUM%" set localRC=1
goto afterJdkPrep

:skipJdkPrep
set localRC=0
call LogEvent echo DebugMode: Skipping Command

:afterJdkPrep
Call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine
if (%localRC%) NEQ (0) goto updateJDKErrorPrepare
call LogEvent echo Successfully made space for a working copy of the JDK.
call LogEvent BlankLine

:skipMakeSpace

call LogEvent echo Creating working copy of the JDK:
call LogEvent echo Source JDK Path: %JDK_UPDATE_HOME%
call LogEvent echo Target JDK Path: %TMP%\java_%PTFNUM%
call LogEvent BlankLine

set CommandName=CopyJDKForWork
set CommandDescription=Create a working copy of the JDK before applying the JDK update.
set CommandBackup=None is available
set CommandLog=None is available

set CMD=xcopy "%JDK_UPDATE_HOME%\*" "%TMP%\java_%PTFNUM%" /e /q /i

if (%DEBUGMODE%) == (true) goto :skipJdkCopy

call LogEvent xcopy "%JDK_UPDATE_HOME%\*" "%TMP%\java_%PTFNUM%" /e /q /i
set localRC=%errorlevel%
goto afterJdkCopy

:skipJdkCopy
set localRC=0
Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
Call LogEvent echo %CMD%
call LogEvent echo DebugMode: Skipping Command

:afterJdkCopy
Call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine

if (%localRC%) NEQ (0) goto updateJDKErrorCopy
call LogEvent echo Successfully created a working copy of the JDK.
call LogEvent BlankLine

call LogEvent echo Updating the working copy of the JDK.
call LogEvent BlankLine

set CommandName=RunJDKUpdate
set CommandDescription=Run java on the supplied JDK update jar file.
set CommandBackup=%BACKUP_DIR%\jdk_%PTFNUM%_backup.jar
set CommandLog=%LOGS_DIR%\jdk_%PTFNUM%.log

call LogEvent echo Running update from jar file:
call LogEvent echo jdk_%PTFNUM%.jar
call LogEvent echo Running update against target:
call LogEvent echo %JDK_UPDATE_HOME%
call LogEvent echo Creating backup jar file:
call LogEvent echo %CommandBackup%
call LogEvent echo Creating update log file:
call LogEvent echo %CommandLog%
Call LogEvent BlankLine

rem --- Echo a hyperlink from the summary log file to the detail log file.

Set CMD="%TMP%\java_%PTFNUM%\jre\bin\java" -jar jdk_%PTFNUM%.jar -target "%JDK_UPDATE_HOME%" -backupJar "%CommandBackup%" -log "%CommandLog%" -SkipVer -TmpDir "%TMP%" %OverWriteBUJ%

Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
Call LogEvent echo %CMD%

if (%DEBUGMODE%) == (true) goto :skipJdkCmd

Set errorlevel=
%CMD%
Set localRC=%errorlevel%
goto afterJdkCmd

:skipJdkCmd
call LogEvent echo DebugMode: Skipping Command
Set localRC=0

:afterJdkCmd
Call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine
if (%localRC%) NEQ (0) goto updateJDKErrorRun
call LogEvent echo Successfully updated the working copy of the JDK.
call LogEvent BlankLine

set CommandName=RemoveWorkJDK
set CommandDescription=Removing the working copy of the JDK.
set CommandBackup=None is available
set CommandLog=None is available

call LogEvent echo Pausing 10 seconds to allow the JDK to settle.
GetInput Sleep 10 quiet
call LogEvent echo Completed pause.

set CMD=rmdir "%TMP%\java_%PTFNUM%" /S/Q

Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
Call LogEvent echo %CMD%

if (%DEBUGMODE%) == (true) goto :skipRemoveJdkCmd

rmdir "%TMP%\java_%PTFNUM%" /S/Q
set localRC=0
if exist "%TMP%\java_%PTFNUM%" set localRC=1
goto afterRemoveJdkCmd

:skipRemoveJdkCmd
call LogEvent echo DebugMode: Skipping Command
set localRC=0

:afterRemoveJdkCmd
call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine
if (%localRC%) NEQ (0) goto updateJDKErrorRemove
call LogEvent echo The working copy of the JDK was removed.
call LogEvent BlankLine

call LogEvent copy "%JDK_UPDATE_HOME%\jre\lib\ext\gskikm.jar" "%WAS_UPDATE_HOME%\lib\gskikm.jar" 
copy "%JDK_UPDATE_HOME%\jre\lib\ext\gskikm.jar" "%WAS_UPDATE_HOME%\lib\gskikm.jar" 
call LogEvent del "%JDK_UPDATE_HOME%\jre\lib\ext\gskikm.jar"
del "%JDK_UPDATE_HOME%\jre\lib\ext\gskikm.jar"
call LogEvent BlankLine

call LogEvent echo The update of the Java Development Kit was successful.
call LogEvent BlankLine
goto updateIHS

:skipUpdateJDK
call LogEvent echo The update of the Java Development Kit was disabled.
call LogEvent BlankLine
goto updateIHS

:updateJDKErrorPrepare
call LogEvent echo An error occurred while making space for the working copy
call LogEvent echo of the Java Development Kit.
call LogEvent BlankLine
goto updateError

:updateJDKErrorCopy
call LogEvent echo An error occurred during the initial copy step of the
call LogEvent echo the Java Development Kit update.
call LogEvent BlankLine
goto updateError

:updateJDKErrorRun
call LogEvent echo An error occurred during the update step of the
call LogEvent echo the Java Development Kit update.
call LogEvent BlankLine
goto cleanupJDK

:updateJDKErrorPlace
call LogEvent echo An error occurred during the placement step of the
call LogEvent echo the Java Development Kit update.
call LogEvent BlankLine
goto cleanupJDK

:updateJDKErrorRemove
call LogEvent echo An error occurred during the removal of the working
call LogEvent echo copy of the Java Development Kit.
call LogEvent BlankLine
goto updateError

:cleanupJDK
call LogEvent echo Removing working copy of the JDK.
call LogEvent echo (An error has already occurred -- complete error
call LogEvent echo reporting is not available for this operation.)
call LogEvent BlankLine
call LogEvent echo Target JDK Path:
call LogEvent echo %TMP%\java_%PTFNUM%
call LogEvent BlankLine

rmdir "%TMP%\java_%PTFNUM%" /S/Q
if exist "%TMP%\java_%PTFNUM%" goto cleanupJDKError

call LogEvent echo Removed working copy of the JDK.
call LogEvent BlankLine
goto updateError

:cleanupJDKError
set localRC=1
call LogEvent echo ERROR: Unable to remove the working copy of the JDK.
call LogEvent BlankLine
goto updateError


:updateIHS
if (%INSTALL_IHS%) == (false) goto skipUpdateIHS

set SectionName=UpdateIHS

call LogEvent echo Performing the base IBM HTTP Server update.
call LogEvent BlankLine

set CommandName=RunIHSUpdate
set CommandDescription=Run java on the supplied IHS update jar file.

set CommandBackup=%BACKUP_DIR%\ihs_%PTFNUM%_backup.jar
set CommandLog=%LOGS_DIR%\ihs_%PTFNUM%.log

call LogEvent echo Running update from jar file:
call LogEvent echo ihs_%PTFNUM%.jar
call LogEvent echo Running update against target:
call LogEvent echo %IHS_UPDATE_HOME%
call LogEvent echo Creating backup jar file:
call LogEvent echo %CommandBackup%
call LogEvent echo Creating update log file:
call LogEvent echo %CommandLog%
Call LogEvent BlankLine

rem --- Echo a hyperlink from the summary log file to the detail log file.

Set CMD="%JDK_UPDATE_HOME%\jre\bin\java" -jar ihs_%PTFNUM%.jar -target "%IHS_UPDATE_HOME%" -backupJar "%CommandBackup%" -log "%CommandLog%" -SkipVer -TmpDir "%TMP%" %OverWriteBUJ%

Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
call LogEvent echo %CMD%

if (%DEBUGMODE%) == (true) goto :skipIHSCmd

Set errorlevel=
%CMD%
set localRC=%errorlevel%
goto afterIHSCmd

:skipIHSCmd
call LogEvent echo DebugMode: Skipping Command
set localRC=0

:afterIHSCmd
call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine
if (%localRC%) NEQ (0) goto updateIHSError
call LogEvent echo the Base IHS update was successful.
call LogEvent BlankLine

call LogEvent echo Updating GSKIT.
call LogEvent BlankLine

set CommandName=RunGSkitUpdate
set CommandDescription=Run the IHS supplied GSK setup program.
set CommandBackup=None is available
set CommandLog=None is available

set CMD="%IHS_UPDATE_HOME%\skit\setup" GSkit5 "%SystemDrive%\Program Files" -s -f2.\gskit5.log

Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
call LogEvent echo %CMD%

if (%DEBUGMODE%) == (true) goto :skipGSKITCmd

Set errorlevel=
"%IHS_UPDATE_HOME%\skit\setup" GSkit5 "%SystemDrive%\Program Files" -s -f2.\gskit5.log
set localRC=%errorlevel%
goto afterGSKITCmd

:skipGSKITCmd
call LogEvent echo DebugMode: Skipping Command
set localRC=0

:afterGSKITCmd
call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine
if (%localRC%) NEQ (0) goto updateIHSErrorGSKIT
call LogEvent echo The GSKIT update was successful.
call LogEvent BlankLine
goto updateAfpaSys

:updateAfpaSys
call LogEvent echo Performing the afpa.sys update.
call LogEvent BlankLine
set CommandName=RunAfpa.sysUpdate
set CommandDescription=Run the update to install the new afpa.sys file.
set CommandBackup=None is available
set CommandLog=None is available

if not defined windir goto noWindirEnv

Set CMD="%IHS_UPDATE_HOME%\AfpaCmd.exe" -i

Call LogEvent echo Command: %SectionName%: %CommandName%
Call LogEvent echo %CommandDescription%
Call LogEvent BlankLine
call LogEvent echo %CMD%

if (%DEBUGMODE%) == (true) goto :skipAfpaSysCmd
call LogEvent echo Copying files...
call LogEvent echo copy "%IHS_UPDATE_HOME%\system32\ApachePerformanceMonitor.dll" "%windir%\system32\ApachePerformanceMonitor.dll"
call LogEvent echo copy "%IHS_UPDATE_HOME%\system32\drivers\afpa.sys" "%windir%\system32\drivers\afpa.sys"
copy "%IHS_UPDATE_HOME%\system32\ApachePerformanceMonitor.dll" "%windir%\system32\ApachePerformanceMonitor.dll"
copy "%IHS_UPDATE_HOME%\system32\drivers\afpa.sys" "%windir%\system32\drivers\afpa.sys"
call LogEvent echo Running Command:
call LogEvent echo %CMD%

Set errorlevel=
%CMD%
set localRC=%errorlevel%
goto afterAfpaSysCmd

:noWindirEnv
call LogEvent echo ERROR: There is no environment windir set.
call LogEvent echo ERROR: The afpa.sys update will not occur.
goto updateIHSErrorAfpaSys

:skipAfpaSysCmd
call LogEvent echo DebugMode: Skipping Command
set localRC=0

:afterAfpaSysCmd
call LogEvent echo returnCode=%localRC%
call LogEvent BlankLine
if (%localRC%) NEQ (0) goto updateIHSErrorAfpaSys
call LogEvent echo The afpa.sys update was successful.
call LogEvent BlankLine
goto cleanupAfpaSysFiles

:cleanupAfpaSysFiles
call LogEvent echo Cleaning up IHS files.
call LogEvent echo rmdir "%IHS_UPDATE_HOME%\system32" /S/Q
rmdir "%IHS_UPDATE_HOME%\system32" /S/Q
call LogEvent echo del "%IHS_UPDATE_HOME%\AfpaCmd.exe"
del "%IHS_UPDATE_HOME%\AfpaCmd.exe"
call LogEvent BlankLine
call LogEvent echo The update of the IBM HTTP Server update was successful.
goto updateJ2C

:skipUpdateIHS
call LogEvent echo The update of the IBM HTTP Server was disabled.
call LogEvent BlankLine
goto updateJ2C

:updateIHSError
call LogEvent echo An error occurred during the IBM HTTP Server update.
call LogEvent BlankLine
goto updateError

:updateIHSErrorGSKIT
call LogEvent echo An error occurred during the GSKIT update.
call LogEvent BlankLine
goto updateError

:updateIHSErrorAfpaSys
call LogEvent echo An error occurred during the afpa.sys update.
call LogEvent BlankLine
goto updateError

:updateJ2C
goto z_performUpdates

:updateError
call LogEvent echo Update Error Report:
call LogEvent BlankLine
call LogEvent echo Section Name: %SectionName%
call LogEvent echo Command Name: %CommandName%
call LogEvent echo Description: %CommandDescription%
call LogEvent echo Command Log File: %CommandLog%
call LogEvent echo Command Backup File: %CommandBackup%
call LogEvent BlankLine
goto z_performUpdates

:z_performUpdates
goto complete

rem Common finalization section.

:complete
call LogEvent echo %PTFDescription% install complete.
call LogEvent BlankLine

if (%LEAVE_LOG%) == (true) goto completedSummary
set NEW_SUMMARYLOG="%LOGS_DIR%\%SUMMARYBASE%"
set OLD_SUMMARYLOG=%SUMMARYLOG%
call LogEvent copy /V %OLD_SUMMARYLOG% %NEW_SUMMARYLOG%
if not %errorlevel% == 0 goto summaryCopyError
set SUMMARYLOG=%NEW_SUMMARYLOG%
call LogEvent BlankLine
call LogEvent echo Copied summary log to:
call LogEvent echo %SUMMARYLOG%
call LogEvent BlankLine
goto completedSummary

:summaryCopyError
call LogEvent echo An error occurred while copying the summary log.
call LogEvent BlankLine
goto completedSummary

:completedSummary
call LogEvent echo A log of installation activity may be found in the summary log file:
call LogEvent echo %SUMMARYLOG%
call LogEvent BlankLine
call LogEvent echo NOTE:
call LogEvent echo Please regenerate the plugin configuration once the server is started in order to update the plugin-cfg.xml file.
call LogEvent BlankLine

goto Egress

:EgressWithError
echo An error occurred during basic initialization.
echo Halting the PTF update.
echo.

:Egress
rem A pause is required when the install is launched through explorer
rem When launched from the explorer the percent % has the full path.

if (%SILENT%) == (true)        Goto FinalEgress
if /I (%0)    == (install)     Goto FinalEgress
if /I (%0)    == (install.bat) Goto FinalEgress
pause

:FinalEgress
@endLocal
